==> huaweicloudsdkgaussdb-3.1.134-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/pause_star_rocks_data_replication.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class PauseStarRocksDataReplication:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'task_name': 'str'
    }

    attribute_map = {
        'task_name': 'task_name'
    }

    def __init__(self, task_name=None):
        """PauseStarRocksDataReplication

        The model defined in huaweicloud sdk

        :param task_name: 同步任务名。字符长度限制3~128位，仅支持英文大小写字母、数字以及下划线。
        :type task_name: str
        """
        
        

        self._task_name = None
        self.discriminator = None

        self.task_name = task_name

    @property
    def task_name(self):
        """Gets the task_name of this PauseStarRocksDataReplication.

        同步任务名。字符长度限制3~128位，仅支持英文大小写字母、数字以及下划线。

        :return: The task_name of this PauseStarRocksDataReplication.
        :rtype: str
        """
        return self._task_name

    @task_name.setter
    def task_name(self, task_name):
        """Sets the task_name of this PauseStarRocksDataReplication.

        同步任务名。字符长度限制3~128位，仅支持英文大小写字母、数字以及下划线。

        :param task_name: The task_name of this PauseStarRocksDataReplication.
        :type task_name: str
        """
        self._task_name = task_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PauseStarRocksDataReplication):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdb-3.1.158-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/pause_star_rocks_data_replication.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class PauseStarRocksDataReplication:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'task_name': 'str'
    }

    attribute_map = {
        'task_name': 'task_name'
    }

    def __init__(self, task_name=None):
        r"""PauseStarRocksDataReplication

        The model defined in huaweicloud sdk

        :param task_name: 同步任务名。字符长度限制3~128位，仅支持英文大小写字母、数字以及下划线。
        :type task_name: str
        """
        
        

        self._task_name = None
        self.discriminator = None

        self.task_name = task_name

    @property
    def task_name(self):
        r"""Gets the task_name of this PauseStarRocksDataReplication.

        同步任务名。字符长度限制3~128位，仅支持英文大小写字母、数字以及下划线。

        :return: The task_name of this PauseStarRocksDataReplication.
        :rtype: str
        """
        return self._task_name

    @task_name.setter
    def task_name(self, task_name):
        r"""Sets the task_name of this PauseStarRocksDataReplication.

        同步任务名。字符长度限制3~128位，仅支持英文大小写字母、数字以及下划线。

        :param task_name: The task_name of this PauseStarRocksDataReplication.
        :type task_name: str
        """
        self._task_name = task_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PauseStarRocksDataReplication):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
